@@ -3,11 +3,12 @@ use warnings;
 
 package SVN::Hooks::CheckProperty;
 {
-  $SVN::Hooks::CheckProperty::VERSION = '1.16';
+  $SVN::Hooks::CheckProperty::VERSION = '1.17';
 }
 # ABSTRACT: Check properties in added files.
 
 use Carp;
+use Data::Util qw(:check);
 use SVN::Hooks;
 
 use Exporter qw/import/;
@@ -20,11 +21,11 @@ my @Checks;
 sub CHECK_PROPERTY {
     my ($where, $prop, $what) = @_;
 
-    defined $where and (not ref $where or ref $where eq 'Regexp')
+    is_string($where) || is_rx($where)
 	or croak "$HOOK: first argument must be a STRING or a qr/Regexp/\n";
-    defined $prop and not ref $prop
+    is_string($prop)
 	or croak "$HOOK: second argument must be a STRING\n";
-    not defined $what or not ref $what or ref $what eq 'Regexp'
+    ! defined $what || is_string($what) || is_rx($what)
 	or croak "$HOOK: third argument must be undefined, or a NUMBER, or a STRING, or a qr/Regexp/\n";
 
     push @Checks, [$where, $prop => $what];
@@ -42,33 +43,27 @@ sub pre_commit {
     foreach my $added ($svnlook->added()) {
 	foreach my $check (@Checks) {
 	    my ($where, $prop, $what) = @$check;
-	    if (ref $where eq 'Regexp' and $added =~ $where or
-		    $where eq substr($added, 0, length $where)) {
+	    if (is_rx($where) && $added =~ $where
+		    || is_string($where) && $where eq substr($added, 0, length $where)) {
 		my $props = $svnlook->proplist($added);
 		my $is_set = exists $props->{$prop};
 		if (! defined $what) {
 		    $is_set or push @errors, "property $prop must be set for: $added";
-		}
-		elsif (! ref $what) {
-		    if ($what =~ /^\d+$/) {
+		} elsif (is_value($what)) {
+		    if (is_integer($what)) {
 			if ($what) {
-			    $is_set or push @errors, "property $prop must be set for: $added";
-			}
-			else {
+			    $is_set or  push @errors, "property $prop must be set for: $added";
+			} else {
 			    $is_set and push @errors, "property $prop must not be set for: $added";
 			}
-		    }
-		    elsif (! $is_set) {
+		    } elsif (! $is_set) {
 			push @errors, "property $prop must be set to \"$what\" for: $added";
-		    }
-		    elsif ($props->{$prop} ne $what) {
+		    } elsif ($props->{$prop} ne $what) {
 			push @errors, "property $prop must be set to \"$what\" and not to \"$props->{$prop}\" for: $added";
 		    }
-		}
-		elsif (! $is_set) {
+		} elsif (! $is_set) {
 		    push @errors, "property $prop must be set and match \"$what\" for: $added";
-		}
-		elsif ($props->{$prop} !~ $what) {
+		} elsif ($props->{$prop} !~ $what) {
 		    push @errors, "property $prop must match \"$what\" but is \"$props->{$prop}\" for: $added";
 		}
 	    }
@@ -92,7 +87,7 @@ SVN::Hooks::CheckProperty - Check properties in added files.
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
