@@ -3,11 +3,12 @@ use warnings;
 
 package SVN::Hooks::DenyChanges;
 {
-  $SVN::Hooks::DenyChanges::VERSION = '1.16';
+  $SVN::Hooks::DenyChanges::VERSION = '1.17';
 }
 # ABSTRACT: Deny some changes in a repository.
 
 use Carp;
+use Data::Util qw(:check);
 use SVN::Hooks;
 
 use Exporter qw/import/;
@@ -22,8 +23,7 @@ sub _deny_change {
     my ($change, @regexes) = @_;
 
     foreach (@regexes) {
-	ref $_ eq 'Regexp'
-	    or croak "$HOOK: all arguments must be qr/Regexp/\n";
+	is_rx($_) or croak "$HOOK: all arguments must be qr/Regexp/\n";
     }
 
     push @{$Deny{$change}}, @regexes;
@@ -52,8 +52,7 @@ sub DENY_EXCEPT_USERS {
     my @users = @_;
 
     foreach my $user (@users) {
-	croak "DENY_EXCEPT_USERS: all arguments must be strings\n"
-	    if ref $user;
+	is_string($user) or croak "DENY_EXCEPT_USERS: all arguments must be strings\n";
 	$Except{$user} = undef;
     }
 
@@ -115,7 +114,7 @@ SVN::Hooks::DenyChanges - Deny some changes in a repository.
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
