@@ -3,11 +3,12 @@ use warnings;
 
 package SVN::Hooks::Generic;
 {
-  $SVN::Hooks::Generic::VERSION = '1.16';
+  $SVN::Hooks::Generic::VERSION = '1.17';
 }
 # ABSTRACT: Implement generic checks for all Subversion hooks.
 
 use Carp;
+use Data::Util qw(:check);
 use SVN::Hooks;
 
 use Exporter qw/import/;
@@ -26,16 +27,13 @@ sub GENERIC {
     while (my ($hook, $functions) = each %args) {
 	$hook =~ /(?:(?:pre|post)-(?:commit|lock|revprop-change|unlock)|start-commit)/
 	    or die "$HOOK: invalid hook name ($hook)";
-	if (! ref $functions) {
-	    die "$HOOK: hook '$hook' should be mapped to a reference.\n";
-	} elsif (ref $functions eq 'CODE') {
+	if (is_code_ref($functions)) {
 	    $functions = [$functions];
-	} elsif (ref $functions ne 'ARRAY') {
-	    die "$HOOK: hook '$hook' should be mapped to a CODE-ref or to an ARRAY of CODE-refs.\n";
+	} elsif (! is_array_ref($functions)) {
+	    die "$HOOK: hook '$hook' should be mapped to a CODE-ref or to an ARRAY-ref.\n";
 	}
 	foreach my $foo (@$functions) {
-	    ref $foo and ref $foo eq 'CODE'
-		or die "$HOOK: hook '$hook' should be mapped to CODE-refs.\n";
+	    is_code_ref($foo) or die "$HOOK: hook '$hook' should be mapped to CODE-refs.\n";
 	    $SVN::Hooks::Hooks{$hook}{$foo} ||= sub { $foo->(@_); };
 	}
     }
@@ -54,7 +52,7 @@ SVN::Hooks::Generic - Implement generic checks for all Subversion hooks.
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 SYNOPSIS
 
